==> nextcloud-app-calendar-1%3A5.3.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/nn_NO.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s has lagt ut  kalenderen »%s«",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Me vil sei ifrå om at %shar lagt ut kalenderen »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Tudelu!",
    "Calendar" : "Kalender",
    "Prepare for %s" : "Klargjer for %s",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Veke",
    "Month" : "Månad",
    "Year" : "År",
    "Copy link" : "Kopier lenkje",
    "Edit" : "Rediger",
    "Delete" : "Slett",
    "New calendar" : "Ny kalender",
    "Export" : "Eksporter",
    "Empty trash bin" : "Tøm søppel korg",
    "Name" : "Namn",
    "Deleted" : "Sletta",
    "Restore" : "Gjenopprett",
    "Delete permanently" : "Slett for godt",
    "Share link" : "Del lenkje",
    "can edit" : "kan endra",
    "Save" : "Lagre",
    "Cancel" : "Avbryt",
    "List view" : "Liste visning",
    "Actions" : "Handlingar",
    "Update" : "Oppdater",
    "Location" : "Stad",
    "Description" : "Skildring",
    "to" : "til",
    "Add" : "Legg til",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sunday" : "Søndag",
    "Your email address" : "Di epost-adresse",
    "Email" : "E-post",
    "days" : "dagar",
    "Delete file" : "Slett fil",
    "Unknown" : "Ukjend",
    "Tentative" : "Førebels",
    "Attendees" : "Deltakarar",
    "Repeat" : "Gjenta",
    "never" : "aldri",
    "after" : "etter",
    "Room type" : "Romtype",
    "Global" : "Global",
    "Personal" : "Personleg",
    "Edit event" : "Rediger hending",
    "Close" : "Lukk",
    "Daily" : "Kvar dag",
    "Weekly" : "Kvar veke",
    "second" : "andre",
    "last" : "siste",
    "Meeting room" : "Møterom",
    "Other" : "Anna",
    "When shared show full event" : "Når delt, vis heile hendinga",
    "When shared show only busy" : "Når delt, vis berre oppteken",
    "When shared hide this event" : "Når delt, gøym denne hendinga",
    "Status" : "Status",
    "Confirmed" : "Stadfesta",
    "Details" : "Detaljar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A6.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/nn_NO.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s has lagt ut  kalenderen »%s«",
    "Hello," : "Hallo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Me vil sei ifrå om at %shar lagt ut kalenderen »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Tudelu!",
    "Calendar" : "Kalender",
    "Prepare for %s" : "Klargjer for %s",
    "Location:" : "Plassering:",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Veke",
    "Month" : "Månad",
    "Year" : "År",
    "Copy link" : "Kopier lenkje",
    "Edit" : "Rediger",
    "Delete" : "Slett",
    "New calendar" : "Ny kalender",
    "Export" : "Eksporter",
    "Empty trash bin" : "Tøm søppel korg",
    "Name" : "Namn",
    "Deleted" : "Sletta",
    "Restore" : "Gjenopprett",
    "Delete permanently" : "Slett for godt",
    "Share link" : "Del lenkje",
    "Save" : "Lagre",
    "Cancel" : "Avbryt",
    "Automatic ({timezone})" : "Automatisk ({tidssone})",
    "List view" : "Liste visning",
    "Actions" : "Handlingar",
    "General" : "Generelt",
    "Appearance" : "Utsjånad",
    "Update" : "Oppdater",
    "Location" : "Stad",
    "Description" : "Skildring",
    "to" : "til",
    "Add" : "Legg til",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sunday" : "Søndag",
    "Your email address" : "Di epost-adresse",
    "Email" : "E-post",
    "days" : "dagar",
    "Delete file" : "Slett fil",
    "Unknown" : "Ukjend",
    "Tentative" : "Førebels",
    "Attendees" : "Deltakarar",
    "Repeat" : "Gjenta",
    "never" : "aldri",
    "after" : "etter",
    "Room type" : "Romtype",
    "Remove participant" : "Eksterne deltakarar",
    "None" : "Ingen",
    "Global" : "Global",
    "Personal" : "Personleg",
    "Edit event" : "Rediger hending",
    "Close" : "Lukk",
    "Participants" : "Deltakarar",
    "Daily" : "Kvar dag",
    "Weekly" : "Kvar veke",
    "second" : "andre",
    "last" : "siste",
    "Meeting room" : "Møterom",
    "Other" : "Anna",
    "When shared show full event" : "Når delt, vis heile hendinga",
    "When shared show only busy" : "Når delt, vis berre oppteken",
    "When shared hide this event" : "Når delt, gøym denne hendinga",
    "Status" : "Status",
    "Confirmed" : "Stadfesta",
    "can edit" : "kan endra"
},
"nplurals=2; plural=(n != 1);");
